<?php

namespace Asadi\Payment\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Payment\Interfaces\PaymentRepositoryInterface;
use Asadi\Payment\Repositories\Presenter\PaymentItemTransformer;

/**
 * Pubic API controller class.
 */
class PaymentPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Payment\Interfaces\PaymentRepositoryInterface $payment
     *
     * @return type
     */
    public function __construct(PaymentRepositoryInterface $payment)
    {
        $this->repository = $payment;
        parent::__construct();
    }

    /**
     * Show payment's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $payments = $this->repository
            ->setPresenter('\\Asadi\\Payment\\Repositories\\Presenter\\PaymentListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $payments['code'] = 2000;
        return response()->json($payments)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show payment.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $payment = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($payment)) {
            $payment         = $this->itemPresenter($module, new PaymentItemTransformer);
            $payment['code'] = 2001;
            return response()->json($payment)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
