<?php

namespace Asadi\Payment\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Asadi\Payment\Http\Requests\PaymentRequest;
use Asadi\Payment\Interfaces\PaymentRepositoryInterface;
use Asadi\Payment\Models\Payment;

class PaymentUserController extends BaseController
{
    /**
     * Initialize payment controller.
     *
     * @param type PaymentRepositoryInterface $payment
     *
     * @return type
     */
    public function __construct(PaymentRepositoryInterface $payment)
    {
        $this->repository = $payment;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Payment\Repositories\Criteria\PaymentUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PaymentRequest $request)
    {
        $payments = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('payment::payment.names'));

        return $this->theme->of('payment::user.payment.index', compact('payments'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Payment $payment
     *
     * @return Response
     */
    public function show(PaymentRequest $request, Payment $payment)
    {
        Form::populate($payment);

        return $this->theme->of('payment::user.payment.show', compact('payment'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PaymentRequest $request)
    {

        $payment = $this->repository->newInstance([]);
        Form::populate($payment);

        $this->theme->prependTitle(trans('payment::payment.names'));
        return $this->theme->of('payment::user.payment.create', compact('payment'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PaymentRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $payment = $this->repository->create($attributes);

            return redirect(trans_url('/user/payment/payment'))
                -> with('message', trans('messages.success.created', ['Module' => trans('payment::payment.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Payment $payment
     *
     * @return Response
     */
    public function edit(PaymentRequest $request, Payment $payment)
    {

        Form::populate($payment);
        $this->theme->prependTitle(trans('payment::payment.names'));

        return $this->theme->of('payment::user.payment.edit', compact('payment'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Payment $payment
     *
     * @return Response
     */
    public function update(PaymentRequest $request, Payment $payment)
    {
        try {
            $this->repository->update($request->all(), $payment->getRouteKey());

            return redirect(trans_url('/user/payment/payment'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('payment::payment.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PaymentRequest $request, Payment $payment)
    {
        try {
            $this->repository->delete($payment->getRouteKey());
            return redirect(trans_url('/user/payment/payment'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('payment::payment.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
