<?php

namespace Asadi\Payment\Http\Controllers;
use Litepie\Payment\Http\Requests\PaymentRequest;
use Litepie\Payment\Models\Payment;

trait PaymentWorkflow {
	
    /**
     * Workflow controller function for payment.
     *
     * @param Model   $payment
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(PaymentRequest $request, Payment $payment, $step)
    {

        try {

            $payment->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('payment::payment.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/payment/payment/' . $payment->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/payment/payment/' . $payment->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for payment.
     *
     * @param Model   $payment
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Payment $payment, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $payment->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('payment::payment.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('payment::admin.payment.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('payment::admin.payment.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('payment::admin.payment.message', $data)->render();

        }

    }
}