<?php

namespace Asadi\Payment\Policies;

use App\User;
use Asadi\Payment\Models\Payment;

class PaymentPolicy
{

    /**
     * Determine if the given user can view the payment.
     *
     * @param User $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function view(User $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $payment->user_id;
    }

    /**
     * Determine if the given user can create a payment.
     *
     * @param User $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('payment.payment.create');
    }

    /**
     * Determine if the given user can update the given payment.
     *
     * @param User $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function update(User $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $payment->user_id;
    }

    /**
     * Determine if the given user can delete the given payment.
     *
     * @param User $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function destroy(User $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $payment->user_id;
    }

    /**
     * Determine if the given user can verify the given payment.
     *
     * @param User $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function verify(User $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('payment.payment.verify') 
        && $user->is('manager')
        && $payment->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given payment.
     *
     * @param User $user
     * @param Payment $payment
     *
     * @return bool
     */
    public function approve(User $user, Payment $payment)
    {
        if ($user->canDo('payment.payment.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
