<?php

namespace Asadi\Payment\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Payment\Models\Payment;

class PaymentAction
{
    /**
     * Perform the complete action.
     *
     * @param Payment $payment
     *
     * @return Payment
     */
    public function complete(Payment $payment)
    {
        try {
            $payment->status = 'complete';
            return $payment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Payment $payment
     *
     * @return Payment
     */public function verify(Payment $payment)
    {
        try {
            $payment->status = 'verify';
            return $payment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Payment $payment
     *
     * @return Payment
     */public function approve(Payment $payment)
    {
        try {
            $payment->status = 'approve';
            return $payment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Payment $payment
     *
     * @return Payment
     */public function publish(Payment $payment)
    {
        try {
            $payment->status = 'publish';
            return $payment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Payment $payment
     *
     * @return Payment
     */
    public function archive(Payment $payment)
    {
        try {
            $payment->status = 'archive';
            return $payment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Payment $payment
     *
     * @return Payment
     */
    public function unpublish(Payment $payment)
    {
        try {
            $payment->status = 'unpublish';
            return $payment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
